import { signal } from '@angular/core';
import { produce } from 'immer';

/** Create a `Signal` with immutable state that can be set or updated directly.*/
function immutableSignal(...args) {
    const [value, ...rest] = args;
    const s = signal(produce(value, (v) => v), ...rest);
    return new Proxy(s, {
        get(target, property, receiver) {
            switch (property) {
                case 'mutate':
                    return (mutatorFn) => {
                        return target.update((val) => produce(val, mutatorFn));
                    };
                case 'set':
                    return (val) => {
                        return target.set(produce(val, (v) => v));
                    };
                case 'update':
                    return (updateFn) => {
                        return target.update((val) => produce(val, updateFn));
                    };
                default:
                    return Reflect.get(target, property, receiver);
            }
        },
    });
}

/*
 * Public API Surface of ngx-immutable-signal
 */

/**
 * Generated bundle index. Do not edit.
 */

export { immutableSignal };
//# sourceMappingURL=ngx-immutable-signal.mjs.map
